<!-- Begin Title, generated by Fern  -->

# Sayari-analytics Python Library

[![fern shield](https://img.shields.io/badge/%F0%9F%8C%BF-SDK%20generated%20by%20Fern-brightgreen)](https://github.com/fern-api/fern)

The [Sayari](https://sayari.com) Python SDK provides convenient access to the Sayari API from applications written in Python.

<!-- End Title  -->

# Documentation

Please see our [docs site](http://documentation.sayari.com) for more info and or to get in touch with us.

<!-- Begin Installation, generated by Fern  -->

# Installation

```sh
pip install --upgrade sayari
```

<!-- End Installation  -->

<!-- Begin Usage, generated by Fern  -->

# Usage

```python
from sayari.client import Sayari

client = Sayari(
    client_id="YOUR_CLIENT_ID",
    client_secret="YOUR_CLIENT_SECRET",
)
```

<!-- End Usage  -->

<!-- Begin Async Usage, generated by Fern  -->

# Async Client

```python
from sayari.client import AsyncSayari

client = AsyncSayari(
    client_id="YOUR_CLIENT_ID",
    client_secret="YOUR_CLIENT_SECRET",
)
```

<!-- End Async Usage  -->

# OAuth

The Sayari client includes automatic OAuth access token retrieval, refreshing it as needed. Simply specify the `client_id`
and `client_secret` (shown above) and your access token will be used for every authenticated request.

<!-- Begin Status, generated by Fern  -->

# Beta Status

This SDK is in beta, and there may be breaking changes between versions without a major
version update. Therefore, we recommend pinning the package version to a specific version.
This way, you can install the same version each time without breaking changes.

<!-- End Status  -->
